<?php
/**
 * Word blog functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package world-blog
 */

if ( ! function_exists( 'world_blog_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function world_blog_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on world-blog, use a find and replace
		 * to change 'world-blog' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'world-blog', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

         // Add menus.
         register_nav_menus( array(
        'primary' => __( 'Primary Menu', 'world-blog' ),

         ) );
	

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'world_blog_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
}
endif; // world_blog_setup

add_action( 'after_setup_theme', 'world_blog_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function world_blog_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'world_blog_content_width', 640 );
}
add_action( 'after_setup_theme', 'world_blog_content_width', 0 );



if ( ! function_exists( 'world_blog_widgets_init' ) ) :

function world_blog_widgets_init() {

    /*
     * Register widget areas.
     */
	 
	 
	   register_sidebar( array(
        'name' => __( 'Right Sidebar', 'world-blog' ),
        'id' => 'right_sidebar',
        'before_widget' => '<li id="%1$s" class="widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h3 class="widgettitle" </h3>',
        'after_title' => '</h3>'
    ) );

    register_sidebar( array(
        'name' => __( 'Footer Widget 1', 'world-blog' ),
        'id' => 'footer_widget_1',
        'before_widget' => '<li id="%1$s" class="footer-widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>'
    ) );

    register_sidebar( array(
        'name' => __( 'Footer Widget 2', 'world-blog' ),
        'id' => 'footer_widget_2',
        'before_widget' => '<li id="%1$s" class="footer-widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>'
    ) );

    register_sidebar( array(
        'name' => __( 'Footer Widget 3', 'world-blog' ),
        'id' => 'footer_widget_3',
        'before_widget' => '<li id="%1$s" class="footer-widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>'
    ) );

    register_sidebar( array(
        'name' => __( 'Footer Widget 4', 'world-blog' ),
        'id' => 'footer_widget_4',
        'before_widget' => '<li id="%1$s" class="footer-widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>'
    ) );

	 
	 
	 

}
add_action( 'widgets_init', 'world_blog_widgets_init' );
endif;// world-blog_widgets_init



if ( ! function_exists( 'world_blog_customize_register' ) ) :

function world_blog_customize_register( $wp_customize ) {
	
	 // Theme Setting //
	
     $wp_customize->add_panel( 'theme_setting', array(
		'priority'       => 2,
		'capability'     => 'edit_theme_options',
		'title'      => __('Theme Settings', 'world-blog'),
	 ) );
	
	 $wp_customize->add_section(
        'top_section',
        array(
            'title' => __('Social Layout','world-blog'),
			'panel'  => 'theme_setting',)

     );

    $wp_customize->add_setting( 'top_section_face_url', array(
        'type' => 'theme_mod',
		'default' => '#',
		'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw'
    ));

    $wp_customize->add_control( 'top_section_face_url', array(
        'label' => __( 'Facebook Url', 'world-blog' ),
        'type' => 'url',
        'section' => 'top_section'
    ));

    $wp_customize->add_setting( 'top_section_twitter_url', array(
        'type' => 'theme_mod',
		'capability'     => 'edit_theme_options',
		'default' => '#',
        'sanitize_callback' => 'esc_url_raw'
    ));

    $wp_customize->add_control( 'top_section_twitter_url', array(
        'label' => __( 'Twitter Url', 'world-blog' ),
        'type' => 'url',
        'section' => 'top_section'
    ));

    $wp_customize->add_setting( 'top_section_instagram_url', array(
        'type' => 'theme_mod',
		'default' => '#',
		'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw'
    ));

    $wp_customize->add_control( 'top_section_instagram_url', array(
        'label' => __( 'Instagram Url', 'world-blog' ),
        'type' => 'url',
        'section' => 'top_section'
    ));

    $wp_customize->add_setting( 'top_section_linked_url', array(
        'type' => 'theme_mod',
		'default' => '#',
		'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw'
    ));

    $wp_customize->add_control( 'top_section_linked_url', array(
        'label' => __( 'Linkedin Url', 'world-blog' ),
        'type' => 'url',
        'section' => 'top_section'
    ));

    $wp_customize->add_setting( 'top_section_pinteres_url', array(
        'type' => 'theme_mod',
		'default' => '#',
		'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw'
    ));

    $wp_customize->add_control( 'top_section_pinteres_url', array(
        'label' => __( 'Pinterest Url', 'world-blog' ),
        'type' => 'url',
        'section' => 'top_section'
    ));

    $wp_customize->add_setting( 'top_section_vimeo_url', array(
        'type' => 'theme_mod',
		'default' => '#',
		'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw'
    ));

    $wp_customize->add_control( 'top_section_vimeo_url', array(
        'label' => __( 'Vimeo Url', 'world-blog' ),
        'type' => 'url',
        'section' => 'top_section'
    ));

    $wp_customize->add_setting( 'top_section_youtube_url', array(
        'type' => 'theme_mod',
		'default' => '#',
		'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw'
    ));

    $wp_customize->add_control( 'top_section_youtube_url', array(
        'label' => __( 'Youtube Url', 'world-blog' ),
        'type' => 'url',
        'section' => 'top_section'
    ));

    $wp_customize->add_setting( 'top_section_google_url', array(
        'type' => 'theme_mod',
		'default' => '#',
		'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw'
    ));

    $wp_customize->add_control( 'top_section_google_url', array(
        'label' => __( 'Google Url', 'world-blog' ),
        'type' => 'url',
        'section' => 'top_section'
    ));

	


}
add_action( 'customize_register', 'world_blog_customize_register' );
endif;// world_blog_customize_register

	
if ( ! function_exists( 'world_blog_enqueue_scripts' ) ) :
    function world_blog_enqueue_scripts() {



     /* Js */
	
     wp_enqueue_script( 'jquery', get_template_directory_uri() . '/js/jquery.min.js', array('jquery'), '20151215', true );
     wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array('jquery'), '20151215', true );
	 wp_enqueue_script( 'wrldblog', get_template_directory_uri() . '/js/wrldblog.js', array('jquery'), '20151215', true );
	 wp_enqueue_script( 'script', get_template_directory_uri() . '/js/script.js', array('jquery'), '20151215', true );
	 wp_enqueue_script( 'world-blog-navigation', get_template_directory_uri() . '/js/navigation.js', array('jquery'), '20151215', true );
	 wp_enqueue_script( 'world-blog-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array('jquery'), '20151215', true );
     

        
     /* Styles */
	 
     wp_enqueue_style( 'world-blog-style', get_stylesheet_uri() );  
     wp_enqueue_style( 'world', get_template_directory_uri() . '/css/bootstrap.min.css');
     wp_enqueue_style( 'style', get_template_directory_uri() . '/css/style.css');
     wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome/css/font-awesome.css');


    	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

    }
    add_action( 'wp_enqueue_scripts', 'world_blog_enqueue_scripts' );
endif;




/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Navwalker
 */
require get_template_directory() . '/inc/bootstrap/wp_bootstrap_navwalker.php';